<?php

class ModelCheckServer extends BaseModel {
	// Массив файлов для проверки
	private $fileSystemObjectsChecklist = [
		// Основные директории
		EXBB_DIR_UPLOADS,
	];

	public function checkFilesPermissions() {
		$fileSystemObjectsList = [];

		foreach ($this->fileSystemObjectsChecklist as $object) {
			$objectData = [
				'path' => str_replace(EXBB_ROOT . '/', '', $object),
			];

			$objectData['isExists'] = file_exists($object);

			if ($objectData['isExists']) {
				$objectData['isReadable'] = is_readable($object);
				$objectData['isWriteable'] = is_writeable($object);
			}
			else {
				$objectData['isReadable'] = false;
				$objectData['isWriteable'] = false;
			}

			$fileSystemObjectsList[] = $objectData;
		}

		return $fileSystemObjectsList;
	}

	public function checkServerConfiguration() {
		$serverConfigurationData = [];

		// Проверка версии PHP
		$phpVersionStatus = version_compare(PHP_VERSION, REQUIRED_PHP_VERSION, '>=');

		$serverConfigurationData[] = [
			'code' => 'phpVersion',
			'title' => lang('phpParameterVersion'),
			'status' => $phpVersionStatus,

			'currentValue' => PHP_VERSION,
			'optimalValue' => REQUIRED_PHP_VERSION,
		];

		// Проверка доступности SQLite
		$SQLiteStatus = extension_loaded('sqlite3');

		$serverConfigurationData[] = [
			'code' => 'SQLite3',
			'title' => lang('phpParameterSQLite3'),
			'status' => $SQLiteStatus,

			'currentValue' => ($SQLiteStatus) ? lang('phpParameterSupported') : lang('phpParameterNotSupported'),
			'optimalValue' => lang('phpParameterSupported'),
		];

		// Проверка доступности GZIP
		$gzipStatus = function_exists('ob_gzhandler');

		$serverConfigurationData[] = [
			'code' => 'GZIP',
			'title' => lang('phpParameterGzip'),
			'status' => $gzipStatus,

			'currentValue' => ($gzipStatus) ? lang('phpParameterSupported') : lang('phpParameterNotSupported'),
			'optimalValue' => lang('phpParameterSupported'),
		];

		return $serverConfigurationData;
	}
}